@@ -11,7 +11,7 @@ from collections import Counter
 from PIL import Image
 from transformers import DetrFeatureExtractor, DetrForSegmentation, \
     SegformerFeatureExtractor, SegformerForImageClassification
-from social_net_img_classifier.settings import COCO_CATEGORIES, FEATURES, MODEL_IMG_DIR, MODEL_TEXT_DIR, MODEL_TEXT_BERT_DIR, TOP_OBJECTS
+from social_net_img_classifier.settings import COCO_CATEGORIES, FEATURES, MODEL_IMG_DIR, MODEL_STTM_DIR, MODEL_TEXT_DIR, MODEL_TEXT_BERT_DIR, TOP_OBJECTS
 from social_net_img_classifier.training import TrainClassModel, TrainClfTextModel
 from social_net_img_classifier.aws_utils import AwsS3
 
@@ -100,6 +100,25 @@ class ClassifyText:
         return preds
 
 
+class ClassifySTTM:
+    """
+    :Date: 2022-11-03
+    :Version: 0.1
+    :Authors: Juan David Torres - Whale & Jaguar Consultants S.A.S.
+    :Description: OBTENER GRUPOS DE SHORT TEXT TOPIC MODELLING
+    """
+    def __init__(self):
+        self.model = pickle.loads(AwsS3().read_file(MODEL_STTM_DIR))
+
+    def predict(self, texts):
+        """
+        :Description: receives a list of texts and returns the list with their respective classification
+        :param texts: texts to classify (:type: list)
+        :return: predictions (:type: list)
+        """
+        return [self.model(text)[0]["label"] for text in texts]
+
+
 class GetFeaturesImg:
     """
     :Date: 2022-09-23
