@@ -19,7 +19,7 @@ from multiprocessing import Process, Manager, cpu_count
 from wj_social_net_queries.core.instagram import Instagram
 from wj_social_net_queries.core.twitter import Twitter
 from social_net_img_classifier.aws_utils import AwsS3
-from social_net_img_classifier.classify import ClassifyImg, ClassifyText
+from social_net_img_classifier.classify import ClassifyImg, ClassifySTTM, ClassifyText
 from social_net_img_classifier.db_tools import MySQLtools
 from social_net_img_classifier.utils import GenderByText, NlpUtils, CalcUtils, Location
 from social_net_img_classifier.settings import AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, BRANDS, BUCKET_NAME, BUSINESS_NAME_WORDS, COUNTRIES, \
@@ -39,8 +39,8 @@ IG_TERMS = TERMS["instagram"]
 
 class MainETL:
     """
-    :Date: 2022-10-31
-    :Version: 1.2.1
+    :Date: 2022-11-03
+    :Version: 1.3
     :Author: Joan Felipe Mendoza - Whale & Jaguar Consultants S.A.S.
     :Description: PIPELINE SOBRE AWS
     """
@@ -140,12 +140,15 @@ class MainETL:
                 df["target_text"] = ClassifyText(model_type=model_type).predict(df["text"], clean_mode=None)
             else:
                 df["target_text"] = ClassifyText(model_type=model_type).predict(df["clean_text"], clean_mode=None)
+            df["sttm_group"] = ClassifySTTM().predict(list(df["text"]))
             obj_list, top_list, color_list, img_list, target_list = [], [], [], [], []
             for _, row in df.iterrows():
                 # Clasificar conversaciones por imágenes (sólo las que no dieron positivas por texto)
                 obj_img, top_labels, color_img, img_url, target_img = {}, {}, {}, None, 0
+                urls = row["media_url_https"][:2] if row["media_url_https"] else []
+                if urls:
+                    img_url = urls[0]
                 if row["target_text"] == 0 and row["country_iso2"] in COUNTRIES:
-                    urls = row["media_url_https"][:2] if row["media_url_https"] else []
                     for url in urls:
                         tw_img = ClassifyImg(url)
                         color_img = tw_img.colors
@@ -581,6 +584,5 @@ class Responding:
                     )
             # Cargar a base de datos
             data = pd.DataFrame(data)
-            #MySQLtools(table="report_tw").update_table(data, KEYS["report_tw"], batch=100)
             users_sent = list(data[data["sent"] == 1]["screen_name"])
         return [users_sent, data]
